<?php
namespace SupplyTek\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SupplyTek\Utilities\SessionHandler;
use Zeedhi\Framework\Controller\Metadata;
use Zeedhi\Framework\HTTP\Kernel;

/**
 * Class that handle metadata
 * 
 * @author Danilo D. Vaz
 */
class MetadataSupplyTek extends Metadata 
{
    protected $session;

    const ROUTES_WITH_ID = array(
        "categories" => "categories/category",
        "subcategories" => "categories/subcategory",
        "suppliers" => "suppliers/supplier",
        "products" => "products/product"
    );
    
    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * 
     * @param SessionHandler $sessionHandler Object that allows to manipulate session
     * 
     * @return void
     * 
     * @access public
     * @author Danilo D. Vaz
     */
    public function __construct (SessionHandler $sessionHandler)
    {
        $this->session = $sessionHandler;
    }
    
    /**
     * Return metadata file
     * 
     * Returns metadata file. Checks if its a commom file, GO file or GU file 
     * according operator access profile.
     * 
     * @param Request $request Object that receives data from the caller
     * @param Response $response Object that sends back data to the caller
     *
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Danilo D. Vaz
     */
    public function getMetaDataSupplyTek (Request $request, Response $response)
    {
        try {
            $accessProfile = $this->session->getSessionData('IDPERFILACES');
            $fileName = $request->getParameter('FILE_NAME');
            $type = $request->hasParameter('type') ? $request->getParameter('type') : 'json';
            $metadataPath = Kernel::$metadataSource;

            $this->processRouteWithId($fileName);
            
            $commomPath = $metadataPath . '/commom/' . $fileName . '.' . $type;
            $commomFileExist = file_exists($commomPath);
            
            if ($commomFileExist) {
                $filePath = 'commom/' .  $fileName;
            } else if ($accessProfile == 'GO') {
                $filePath = 'GO/' .  $fileName;
            } else if ($accessProfile == 'GU') {
                $filePath = 'GU/' .  $fileName;
            }
            
            $view = $this->loadFile($filePath, $type);
         
            $response->setMetadata($view);
        } catch (\Exception $e) {
            throw new \Exception("File '$fileName.$type' not found for $accessProfile access");
        }
    }
    
    /**
     * Process route with id
     * 
     * Checks if route is in routes with id list and process the file name.
     * 
     * @param string $fileName String that receives file name sent from frontend
     *
     * @return void
     * 
     * @access private
     * @author Danilo D. Vaz
     */
    private function processRouteWithId (&$fileName)
    {
        $fileNameArray = explode("/", $fileName);

        if (isset(self::ROUTES_WITH_ID[$fileNameArray[0]]) && isset($fileNameArray[1])) {
            if ($fileNameArray[1] == 'frame') {
                $fileName = str_replace('/frame/', '/', $fileName);
            } else {
                $fileName = self::ROUTES_WITH_ID[$fileNameArray[0]];
            }
        }
    }
    
}